@@ -43,26 +43,21 @@ pub struct TemperatureMetrics {
 
 impl TemperatureMetrics {
     pub fn new(reader: TemperatureReader) -> Self {
-        let temperature = Gauge::new("strudel_temperature_celsius", "Temperature in celsius")
-            .expect("unable to declare temperature gauge");
+        let temperature = Gauge::new("strudel_temperature_degrees", "Temperature in celsius").unwrap();
 
-        let humidity = Gauge::new("strudel_relative_humidity", "Relative humidity (0-100)")
-            .expect("unable to declare humidity gauge");
+        let humidity = Gauge::new("strudel_relative_humidity", "Relative humidity (0-100)").unwrap();
 
-        let last_reading = Gauge::new("strudel_last_read_timestamp", "Timestamp of last successful read")
-            .expect("unable to declare last read timestamp gauge");
+        let last_reading = Gauge::new("strudel_last_read_timestamp", "Timestamp of last successful read").unwrap();
 
-        let collections = Counter::new("strudel_collections_total", "Number of attempted reads")
-            .expect("unable to declare collections counter");
+        let collections = Counter::new("strudel_collections_total", "Number of attempted reads").unwrap();
 
-        let errors = CounterVec::new(Opts::new("strudel_errors_total", "Number of failed reads"), &["kind"])
-            .expect("unable to declare errors counter");
+        let errors = CounterVec::new(Opts::new("strudel_errors_total", "Number of failed reads"), &["kind"]).unwrap();
 
         let timing = Histogram::with_opts(HistogramOpts::new(
             "strudel_read_timing_seconds",
             "Time taken to read the sensor in seconds",
         ))
-        .expect("unable to declare timing histogram");
+        .unwrap();
 
         Self {
             reader: Mutex::new(reader),
